/* -*- c-file-style: "GNU" -*- */
/*
 * Copyright (C) CNRS, INRIA, Université Bordeaux 1, Télécom SudParis
 * See COPYING in top-level directory.
 */

#ifndef __EXAMPLE_H__
#define __EXAMPLE_H__

void compute(unsigned usec);

int example_do_event(int n);

/* dummy function #1 */
double example_function1(double*, int);

/* dummy function #2 */
int example_function2(int*, int);

int example_fcall(int *array, int array_size);
int example_push(int *array, int array_size);
int example_pop(int *array, int array_size);
int example_event(int *array, int array_size);
int example_set_var(int *array, int array_size);
int example_add_var(int *array, int array_size);
int example_sub_var(int *array, int array_size);

int example_set_var2(int *array, int array_size);
int example_set_var3(int *array, int array_size);
int example_set_var4(int *array, int array_size);
int example_set_var5(int *array, int array_size);
#endif	/* __EXAMPLE_H__ */
